Learn R Programming

covid19nytimes (version 0.1.3)

covid19nytimes_counties_demo: Demo of US County-Level Data from the NY Times

Description

demo of the daily summary of the Coronavirus (Covid-19) total cases and deaths by county

Usage

covid19nytimes_counties_demo

Arguments

Format

A tibble object

Details

The dataset contains the daily summary of Coronavirus cases (total confirmed and total deaths), by county from the NY Times.

To get the latest data, use refresh_covid19nytimes_states.

Examples

Run this code
# NOT RUN {
data(covid19nytimes_states_demo)

require(dplyr)

# Get top confirmed cases by county,state
covid19nytimes_states_demo %>%
  filter(data_type == "cases_total") %>%
  filter(value == max(value))
# }

Run the code above in your browser using DataLab