Learn R Programming

covid19nytimes (version 0.1.3)

get_info_covid19nytimes: Get information about the datasets provided by covid19nytimes

Description

Returns information about the datasets in this package for covid19R harvesting

Usage

get_info_covid19nytimes()

Arguments

Value

a tibble of information about the datasets in this package

Examples

Run this code
# NOT RUN {
# get the dataset info from this package
get_info_covid19nytimes()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab